#!/bin/bash

# ===================================================================================================================
# Procédure d'installation de WineHQ puis Captvty V2 et V3 pour une distribution fraîchement installée gérée par dnf
# ===================================================================================================================
# Installer cabextract
sudo dnf install cabextract

# Selectionner la version selon la distribution
DISTRO=$(lsb_release -d)
if [[ $DISTRO =~ "Fedora 38" ]]
 then
  sudo dnf config-manager --add-repo https://dl.winehq.org/wine-builds/fedora/38/winehq.repo
elif [[ $DISTRO =~ "Fedora 39" ]]
 then
  sudo dnf config-manager --add-repo https://dl.winehq.org/wine-builds/fedora/39/winehq.repo
else
  echo Distribution non trouvée $DISTRO
  read -t 5 -p ""
  exit
fi

# Installer WineHQ Stable   
sudo dnf install -y winehq-stable

# Installer Winetricks
cd "${HOME}/Téléchargements"
wget  https://raw.githubusercontent.com/Winetricks/winetricks/master/src/winetricks
chmod +x winetricks
sudo mv winetricks /usr/bin
# Par sécurité, forcer la mise à jouro
sudo winetricks --self-update

# Créer le profil 32 bits pour la V2
export WINEARCH=win32
export WINEPREFIX=~/.wine32
echo Chaque fois que Installation de Mono pour wine apparaît, cliquer sur Annuler
wineboot -u

# Créer le profil 64 bits pour la V3
export WINEARCH=win64
export WINEPREFIX=~/.wine64
echo Chaque fois que Installation de Mono pour wine apparaît, cliquer sur Annuler
wineboot -u

echo La suite ne nécessite aucune interaction

# Initialiser le profil 32 bits pour la V2
export WINEARCH=win32
export WINEPREFIX=~/.wine32
# Ignorer toutes les erreurs marshal, coree, ole, fixme
winetricks -q dotnet45 corefonts gdiplus fontsmooth=rgb
# Sélectionner Windows 10
WINEARCH=win32 WINEPREFIX=~/.wine32 winecfg /v win10

# Initialiser le profil 64 bits pour la V3
export WINEARCH=win64
export WINEPREFIX=~/.wine64
# Ignorer toutes les erreurs marshal, coree, ole, fixme
winetricks -q dotnet48 gdiplus comctl32 corefonts fontsmooth=rgb vcrun2010
# Sélectionner Windows 10
WINEARCH=win64 WINEPREFIX=~/.wine64 winecfg /v win10
tmpdir=$(mktemp -d)
cd $tmpdir
cabextract ~/.cache/winetricks/win7sp1/windows6.1-KB976932-X64.exe
cp -rf ./x86_microsoft.windows.common-controls_6595b64144ccf1df_6.0.7601.17514_none_41e6975e2bd6f2b2/comctl32.dll ~/.wine64/drive_c/windows/syswow64/comctl32.dll
cd ~
rm -rf $tmpdir

# ===============================================================================================================
# Installer la V2
#Création conditionnelle du dossier où seront contenus les fichiers du logiciel
test ! -d "$HOME/.captvt2" && mkdir "$HOME/.captvt2"
#Purge du dossier où sont contenus les fichiers du logiciel pour la mise à jour
test -d "$HOME/.captvt2" && rm -rf "$HOME/.captvt2/tools" && rm "$HOME/.captvt2/Captvty.exe" && rm "$HOME/.captvt2/Captvty.exe.config"
#Récupération du programme proprement dit
echo Téléchargement de Captvty V2 ... Patience ...
adresse=$(wget -q -O- 'http://captvty.fr' | sed -n 's/.*href="\(\/\/.\+\.zip\).*/http:\1/p')
test -n "$adresse" && wget -qO /tmp/Captvty.zip "$adresse"
if test -n /tmp/Captvty.zip
then
   unzip -d "$HOME/.captvt2/" /tmp/Captvty.zip &&  rm /tmp/Captvty.zip
fi
# Lancer la V2
sh -c "env WINEARCH=win32 WINEPREFIX=$HOME/.wine32 wine $HOME/.captvt2/Captvty.exe" &

# ===============================================================================================================
# Installer la V3 :
#Création conditionnelle du dossier où seront contenus les fichiers du logiciel
test ! -d "$HOME/.captvt3" && mkdir "$HOME/.captvt3"
#Purge du dossier où sont contenus les fichiers du logiciel pour la mise à jour
test -d "$HOME/.captvt3" && rm -rf "$HOME/.captvt3/bin" && rm "$HOME/.captvt3/Captvty.exe" && rm "$HOME/.captvt3/Captvty.exe.config"
#Récupération du programme proprement dit
echo Téléchargement de Captvty V3 ... Patience ...
adresse=$(wget -q -O- 'http://v3.captvty.fr' | grep "dl zip" | sed -n 's/.*href="\(\/\/.\+\.zip\).*/http:\1/p')
test -n "$adresse" && wget -qO /tmp/captvt3.zip "$adresse"
if test -n /tmp/captvt3.zip
then
   unzip -d "$HOME/.captvt3/" /tmp/captvt3.zip &&  rm /tmp/captvt3.zip
fi
# Lancer la V3
sh -c "env WINEARCH=win64 WINEPREFIX=$HOME/.wine64 wine $HOME/.captvt3/Captvty.exe" &

# ===============================================================================================================


